# Triton Utils

[WIP]

A collection of utility functions and tools for Triton kernel development.

Most code copied from project below:

- [BobMcDear/attorch: A subset of PyTorch's neural network modules, written in Python using OpenAI's Triton.](https://github.com/BobMcDear/attorch)
- [FlagOpen/FlagGems: FlagGems is an operator library for large language models implemented in Triton Language.](https://github.com/FlagOpen/FlagGems)

- pre-commit

```
pip install pre-commit
pre-commit install
pre-commit run --show-diff-on-failure --color=always --all-files
```

## Features



## Installation

```bash
git clone https://github.com/2niuhe/triton-utils.git && cd triton-utils
pip install .
```


## Usage



## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.


**CI**

- action

.github/workflows/code-format-check.yml

- self runner action

.github/workflows/make-build.yml
